/**
 * @since 1.0.0
 */
import { type ApiGatewayManagementApiClient, type ApiGatewayManagementApiClientConfig, type DeleteConnectionCommandInput, type DeleteConnectionCommandOutput, type GetConnectionCommandInput, type GetConnectionCommandOutput, type PostToConnectionCommandInput, type PostToConnectionCommandOutput } from "@aws-sdk/client-apigatewaymanagementapi";
import type { HttpHandlerOptions, ServiceLogger } from "@effect-aws/commons";
import type { Cause } from "effect";
import { Effect, Layer } from "effect";
import * as Instance from "./ApiGatewayManagementApiClientInstance.js";
import type { ForbiddenError, GoneError, LimitExceededError, PayloadTooLargeError, SdkError } from "./Errors.js";
interface ApiGatewayManagementApiService$ {
    readonly _: unique symbol;
    /**
     * @see {@link DeleteConnectionCommand}
     */
    deleteConnection(args: DeleteConnectionCommandInput, options?: HttpHandlerOptions): Effect.Effect<DeleteConnectionCommandOutput, Cause.TimeoutException | SdkError | ForbiddenError | GoneError | LimitExceededError>;
    /**
     * @see {@link GetConnectionCommand}
     */
    getConnection(args: GetConnectionCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetConnectionCommandOutput, Cause.TimeoutException | SdkError | ForbiddenError | GoneError | LimitExceededError>;
    /**
     * @see {@link PostToConnectionCommand}
     */
    postToConnection(args: PostToConnectionCommandInput, options?: HttpHandlerOptions): Effect.Effect<PostToConnectionCommandOutput, Cause.TimeoutException | SdkError | ForbiddenError | GoneError | LimitExceededError | PayloadTooLargeError>;
}
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeApiGatewayManagementApiService: Effect.Effect<ApiGatewayManagementApiService$, never, Instance.ApiGatewayManagementApiClientInstance>;
declare const ApiGatewayManagementApiService_base: import("effect/Context").TagClass<ApiGatewayManagementApiService, "@effect-aws/client-api-gateway-management-api/ApiGatewayManagementApiService", ApiGatewayManagementApiService$> & Effect.Tag.Proxy<ApiGatewayManagementApiService, ApiGatewayManagementApiService$> & {
    use: <X>(body: (_: ApiGatewayManagementApiService$) => X) => [X] extends [Effect.Effect<infer A, infer E, infer R>] ? Effect.Effect<A, E, ApiGatewayManagementApiService | R> : [X] extends [PromiseLike<infer A_1>] ? Effect.Effect<A_1, Cause.UnknownException, ApiGatewayManagementApiService> : Effect.Effect<X, never, ApiGatewayManagementApiService>;
};
/**
 * @since 1.0.0
 * @category models
 */
export declare class ApiGatewayManagementApiService extends ApiGatewayManagementApiService_base {
    static readonly defaultLayer: Layer.Layer<ApiGatewayManagementApiService, never, never>;
    static readonly layer: (config: ApiGatewayManagementApiService.Config) => Layer.Layer<ApiGatewayManagementApiService, never, never>;
    static readonly baseLayer: (evaluate: (defaultConfig: ApiGatewayManagementApiClientConfig) => ApiGatewayManagementApiClient) => Layer.Layer<ApiGatewayManagementApiService, never, never>;
}
/**
 * @since 1.0.0
 */
export declare namespace ApiGatewayManagementApiService {
    /**
     * @since 1.0.0
     */
    interface Config extends Omit<ApiGatewayManagementApiClientConfig, "logger"> {
        readonly logger?: ServiceLogger.ServiceLoggerConstructorProps | true;
    }
}
export {};
//# sourceMappingURL=ApiGatewayManagementApiService.d.ts.map