/**
 * @since 1.0.0
 */
import { DeleteConnectionCommand, GetConnectionCommand, PostToConnectionCommand, } from "@aws-sdk/client-apigatewaymanagementapi";
import { Service } from "@effect-aws/commons";
import { Effect, Layer } from "effect";
import * as Instance from "./ApiGatewayManagementApiClientInstance.js";
import * as ApiGatewayManagementApiServiceConfig from "./ApiGatewayManagementApiServiceConfig.js";
import { AllServiceErrors } from "./Errors.js";
const commands = {
    DeleteConnectionCommand,
    GetConnectionCommand,
    PostToConnectionCommand,
};
/**
 * @since 1.0.0
 * @category constructors
 */
export const makeApiGatewayManagementApiService = Effect.gen(function* () {
    const client = yield* Instance.ApiGatewayManagementApiClientInstance;
    return yield* Service.fromClientAndCommands(client, commands, {
        errorTags: AllServiceErrors,
        resolveClientConfig: ApiGatewayManagementApiServiceConfig.toApiGatewayManagementApiClientConfig,
    });
});
/**
 * @since 1.0.0
 * @category models
 */
export class ApiGatewayManagementApiService extends Effect.Tag("@effect-aws/client-api-gateway-management-api/ApiGatewayManagementApiService")() {
    static defaultLayer = Layer.effect(this, makeApiGatewayManagementApiService).pipe(Layer.provide(Instance.layer));
    static layer = (config) => Layer.effect(this, makeApiGatewayManagementApiService).pipe(Layer.provide(Instance.layer), Layer.provide(ApiGatewayManagementApiServiceConfig.setApiGatewayManagementApiServiceConfig(config)));
    static baseLayer = (evaluate) => Layer.effect(this, makeApiGatewayManagementApiService).pipe(Layer.provide(Layer.effect(Instance.ApiGatewayManagementApiClientInstance, Effect.map(ApiGatewayManagementApiServiceConfig.toApiGatewayManagementApiClientConfig, evaluate))));
}
//# sourceMappingURL=ApiGatewayManagementApiService.js.map